import datetime
from lcwc.category import IncidentCategory
from lcwc.incident import Incident
from lcwc.unit import Unit


class WebIncident(Incident):
    """Represents an incident from the web incident feed"""

    pass
