from lcwc.category import IncidentCategory
from .agency import Agency


KNOWN_FIRE_AGENCIES = [
    Agency(
        category=IncidentCategory.FIRE,
        station_number="02",
        name="Haz-Mat 2 Environmental Fire Rescue",
        url="https://www.facebook.com/Hazmat2",
        address="PO Box 263",
        city="Landisville",
        state="PA",
        zip_code=17538,
        phone="717-537-4197",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="03",
        name="Martindale Fire Co.",
        url="https://www.facebook.com/Martindale-Volunteer-Fire-Company-Station-3-323883971812053/",
        address="542 Gristmill Rd",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-445-7100",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="05",
        name="Strasburg Fire Co.",
        url="http://www.strasburgfire.com/",
        address="PO Box 64",
        city="Strasburg",
        state="PA",
        zip_code=17579,
        phone="717-687-7232",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="07",
        name="Mountville Fire Co.",
        url="http://www.mountvillefire.com/",
        address="26 N Lemon St",
        city="Mountville",
        state="PA",
        zip_code=17554,
        phone="717-285-5456",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="08",
        name="Warwick Emergency Services Commission",
        url="https://www.warwicktownship.org/wesc",
        address="315 Clay Road",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-8900",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="10",
        name="Marietta Fire Co.",
        url="https://www.facebook.com/MPFC10/",
        address="PO Box 93",
        city="Marietta",
        state="PA",
        zip_code=17547,
        phone="717-426-3691",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="11",
        name="Adamstown Fire Co.",
        url="http://adamstownfire.com/",
        address="PO Box 52",
        city="Adamstown",
        state="PA",
        zip_code=19501,
        phone="717-484-4157",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="12",
        name="Akron Fire Co.",
        url="http://www.akronfire.org/",
        address="1229 Main St",
        city="Akron",
        state="PA",
        zip_code=17501,
        phone="717-859-1351",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="13",
        name="Denver Fire Co.",
        url="https://www.facebook.com/DenverFire13",
        address="425 Locust St",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-336-2911",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="14",
        name="Durlach & Mount Airy Fire Co.",
        url="https://www.facebook.com/DurlachMtAiryFireCompany",
        address="880 Durlach Rd",
        city="Stevens",
        state="PA",
        zip_code=17578,
        phone="717-733-6911",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="15",
        name="Ephrata Fire Co.",
        url="http://www.ephratafire.org/",
        address="135 S State St",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-733-4850",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="16",
        name="Lincoln Fire Co.",
        url="http://www.lincolnfireco.com/",
        address="38 S Market St",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-733-6214",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="17-1",
        name="Reamstown Fire Co.",
        url="https://www.reamstownfire.com",
        address="PO Box 276",
        city="Reamstown",
        state="PA",
        zip_code=17567,
        phone="717-336-3958",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="17-2",
        name="Smokestown Fire Co.",
        url="http://www.smokestownfire.com/",
        address="860 Smokestown Rd",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-336-3311",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="17-3",
        name="Stevens Fire Co.",
        url="https://www.facebook.com/Stevens-Fire-Company-245222741428/",
        address="91 Stevens Rd",
        city="Stevens",
        state="PA",
        zip_code=17578,
        phone="717-336-4200",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="18",
        name="Reinholds Fire Co.",
        url="http://www.reinholdsfirecompany.com/",
        address="PO Box 225",
        city="Reinholds",
        state="PA",
        zip_code=17569,
        phone="717-336-7753",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="19",
        name="Schoeneck Fire Co.",
        url="http://schoeneckfire.com/index.html",
        address="125 N King St",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-336-6767",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="20",
        name="Manheim Twp Fire & Rescue",
        url="http://mtfr.net",
        address="1840 Municipal Dr",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-569-6408",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="21",
        name="Brickerville Fire Co.",
        url="http://brickervillefire.net/",
        address="10 Hopeland Rd",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-6711",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="22",
        name="Brunnerville Fire Co.",
        url="http://brunnervillefire.org/",
        address="1302 Church St",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-7270",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="23",
        name="East Petersburg Fire Co.",
        url="http://www.epfc23.com/",
        address="6076 Pine St",
        city="East Petersburg",
        state="PA",
        zip_code=17520,
        phone="717-569-5035",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="24",
        name="Rothsville Fire Co.",
        url="http://rvfc.com/wp/",
        address="2071 Main St",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-7805",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="25",
        name="Lititz Fire Co.",
        url="http://www.lititzfire.org/",
        address="PO Box 391",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-2486",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="26",
        name="Manheim Fire Co.",
        url="http://www.manheimfire.com/",
        address="83 S Main St",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-665-3661",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="27",
        name="Mastersonville Fire Co.",
        url="http://mastersonvillefire.com/",
        address="2121 Meadow View Rd",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-665-5192",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="28",
        name="Penryn Fire Co.",
        url="http://www.penrynfire.com/",
        address="PO Box 163",
        city="Penryn",
        state="PA",
        zip_code=17564,
        phone="717-665-2535",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="29",
        name="West Earl Fire Co.",
        url="http://www.westearlfire.org/",
        address="PO Box 969",
        city="Brownstown",
        state="PA",
        zip_code=17508,
        phone="717-656-6791",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="30",
        name="Weaverland Valley Fire Dept.",
        url="https://www.facebook.com/Weaverland-Valley-Fire-Department-280427685457987/",
        address="PO Box 180",
        city="Terre Hill",
        state="PA",
        zip_code=17581,
        phone="717-445-5072",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="31",
        name="Bareville Fire Co.",
        url="http://barevillefire.com/",
        address="211 E Main St",
        city="Leola",
        state="PA",
        zip_code=17540,
        phone="717-656-7554",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="32",
        name="Fivepointville Fire Co.",
        url="http://fivepointvillefire.net/",
        address="1087 Dry Tavern Rd",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-445-4933",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="33",
        name="Bowmansville Fire Co.",
        url="http://www.bowmansvillefire.com/",
        address="PO Box 302",
        city="Bowmansville",
        state="PA",
        zip_code=17507,
        phone="717-445-6293",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="34",
        name="Caernarvon Fire Co.",
        url="https://www.facebook.com/Caernarvon-Fire-Company-179082158790342/",
        address="2145 Main St",
        city="Narvon",
        state="PA",
        zip_code=17555,
        phone="717-445-7310",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="35",
        name="Farmersville Fire Co.",
        url="https://farmersvillefire.com/",
        address="74 E Farmersville Rd",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-354-5841",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="39",
        name="Garden Spot Fire Rescue",
        url="http://www.gsfr39.net/",
        address="339 E Main St",
        city="New Holland",
        state="PA",
        zip_code=17557,
        phone="717-354-8311",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="41",
        name="Bird-in-Hand Fire Co.",
        url="http://www.bihfire.com/",
        address="313 Enterprise Dr",
        city="Bird-in-Hand",
        state="PA",
        zip_code=17505,
        phone="717-392-0112",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="42",
        name="Gap Fire Co.",
        url="http://www.gapfire.org/",
        address="PO Box 487",
        city="Gap",
        state="PA",
        zip_code=17527,
        phone="717-442-8100",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="43",
        name="Gordonville Fire Co.",
        url="http://www.43fireems.com/",
        address="PO Box 14",
        city="Gordonville",
        state="PA",
        zip_code=17529,
        phone="717-768-3869",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="44",
        name="Intercourse Fire Co.",
        url="http://www.intercoursefire.com/",
        address="PO Box 52",
        city="Intercourse",
        state="PA",
        zip_code=17534,
        phone="717-768-3402",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="45",
        name="Kinzer Fire Co.",
        url="http://www.kinzerfire.com/",
        address="PO Box 82",
        city="Kinzer",
        state="PA",
        zip_code=17535,
        phone="717-442-4121",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="47",
        name="Paradise Fire Co.",
        url="http://www.paradisefire.org/",
        address="PO Box 98",
        city="Paradise",
        state="PA",
        zip_code=17562,
        phone="717-687-7171",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="48",
        name="Ronks Fire Co.",
        url="https://www.facebook.com/Ronksfire48",
        address="134 N Ronks Rd",
        city="Ronks",
        state="PA",
        zip_code=17572,
        phone="717-687-8458",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="49",
        name="White Horse Fire Co.",
        url="http://www.whitehorsefire.org/",
        address="111 White Horse Rd",
        city="Gap",
        state="PA",
        zip_code=17527,
        phone="717-768-3454",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="50",
        name="Willow Street Fire Co.",
        url="http://www.wsfc512.com/",
        address="PO Box 495",
        city="Willow Street",
        state="PA",
        zip_code=17584,
        phone="717-464-4622",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="51",
        name="Bart Twp. Fire Co.",
        url="http://www.bart51.com/",
        address="PO Box 72",
        city="Bart",
        state="PA",
        zip_code=17503,
        phone="717-786-3348",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="52",
        name="Christiana Fire Co.",
        url="http://www.christianafire.com/",
        address="PO Box 46",
        city="Christiana",
        state="PA",
        zip_code=17509,
        phone="610-593-2142",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="53",
        name="Conestoga Fire Co.",
        url="https://www.facebook.com/The-Conestoga-Volunteer-Fire-Company-204013035767/",
        address="PO Box 53",
        city="Conestoga",
        state="PA",
        zip_code=17516,
        phone="717-584-5649",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="54",
        name="Lampeter Fire Co.",
        url="https://www.facebook.com/EngineCompany54",
        address="PO Box 45",
        city="Lampeter",
        state="PA",
        zip_code=17537,
        phone="717-464-2561",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="55",
        name="New Danville Fire Co.",
        url="http://ndfc55.com/",
        address="43 Marticville Rd",
        city="Lancaster",
        state="PA",
        zip_code=17603,
        phone="717-872-2181",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="57",
        name="Quarryville Fire Co.",
        url="http://www.qfd57.com/",
        address="PO Box 143",
        city="Quarryville",
        state="PA",
        zip_code=17566,
        phone="717-786-2898",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="58",
        name="Rawlinsville Fire Co.",
        url="http://www.rvfd58.com/",
        address="PO Box 1",
        city="Holtwood",
        state="PA",
        zip_code=17532,
        phone="717-284-2563",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="59",
        name="Refton Fire Co.",
        url="http://www.refton59fire.com/",
        address="PO Box 7",
        city="Refton",
        state="PA",
        zip_code=17568,
        phone="717-786-9462",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="60",
        name="West Willow Fire Company",
        url="https://www.facebook.com/WestWillowFireCo",
        address="PO Box 2",
        city="West Willow",
        state="PA",
        zip_code=17583,
        phone="717-464-3922",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="61",
        name="Upper Leacock Fire Co.",
        url="http://upperleacockfire.org/",
        address="50 W Main St",
        city="Leola",
        state="PA",
        zip_code=17540,
        phone="717-656-9881",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="62",
        name="Witmer Fire Co.",
        url="http://www.witmerfire.com/",
        address="PO Box 58",
        city="Witmer",
        state="PA",
        zip_code=17585,
        phone="717-393-1259",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="63",
        name="Lafayette Fire Co.",
        url="http://www.lafayettefire.com/",
        address="63 Lafayette Way",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-392-5097",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="64",
        name="Lancaster City Fire Dept.",
        url="http://www.cityoflancasterpa.com/government/fire",
        address="120 N Duke St",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-291-4866",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="66",
        name="Lancaster Twp Fire Dept.",
        url="http://www.ltfd.org/",
        address="PO Box 210",
        city="Bausman",
        state="PA",
        zip_code=17504,
        phone="717-394-5353",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="67",
        name="Rohrerstown Fire Co.",
        url="http://www.67fire.com/",
        address="500 Elizabeth St",
        city="Lancaster",
        state="PA",
        zip_code=17603,
        phone="717-392-6700",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="68",
        name="East Hempfield Twp. Fire Dept.",
        url="http://easthempfield.org",
        address="P O Box 128",
        city="Landisville",
        state="PA",
        zip_code=17538,
        phone="717-898-3100",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="69",
        name="Hempfield Fire Dept.",
        url="http://hempfieldfire.com/",
        address="PO Box 429",
        city="Landisville",
        state="PA",
        zip_code=17538,
        phone="717-898-8112",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="70",
        name="Rheems Fire Co.",
        url="http://www.rheemsfire.com/",
        address="350 Anchor Rd",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-367-1569",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="71",
        name="Bainbridge Fire Co.",
        url="http://www.bfd71.com/",
        address="PO Box 231",
        city="Bainbridge",
        state="PA",
        zip_code=17502,
        phone="717-426-2177",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="74",
        name="Elizabethtown Fire Co.",
        url="http://etownfire.com/",
        address="171 N Mount Joy St",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-367-5300",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="75",
        name="Fire Dept. Mount Joy",
        url="http://www.fdmj.com/",
        address="111 New Haven St",
        city="Mount Joy",
        state="PA",
        zip_code=17552,
        phone="717-653-1600",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="76",
        name="West Hempfield Fire & Rescue",
        url="http://www.westhempfieldfire.com/",
        address="3476 Marietta Avenue",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-285-4929",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="79",
        name="Maytown-E. Donegal Fire Co.",
        url="http://www.maytownedfd.com/",
        address="PO Box 68",
        city="Maytown",
        state="PA",
        zip_code=17550,
        phone="717-426-1290",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="80",
        name="Columbia Borough Fire Dept.",
        url="http://cbfd80.com/",
        address="PO Box 426",
        city="Columbia",
        state="PA",
        zip_code=17512,
        phone="717-684-5844",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="89",
        name="Robert Fulton Fire Co.",
        url="http://rffc89.com/",
        address="PO Box 8",
        city="Peach Bottom",
        state="PA",
        zip_code=17563,
        phone="717-548-8995",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="90",
        name="Blue Rock Fire & Rescue",
        url="http://www.bluerockfire.com/news/index/layoutfile/home",
        address="26 E Charlotte St",
        city="Millersville",
        state="PA",
        zip_code=17551,
        phone="717-872-9345",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="904",
        name="Keystone Wildfire Crew",
        url="http://keystonewildfire.com",
        address="462 Red Hill Road",
        city="Holtwood",
        state="PA",
        zip_code=17532,
        phone="717-872-9345",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="91",
        name="Lancaster County-Wide Communications",
        url="https://www.lcwc911.us/",
        address="PO Box 487",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-664-1100",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="92",
        name="Northern Lancaster County Forest Fire Co.",
        url="https://www.facebook.com/NLCFFC/",
        address="257 E Main Street",
        city="Landisville",
        state="PA",
        zip_code=17538,
        phone="717-898-2411",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="93",
        name="Mt. Joy Twp Forest Fire Crew",
        url="https://www.facebook.com/Mt-Joy-Township-Forestfire-Company-154279834589869/",
        address="771 Greentree Rd",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-653-2100",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="94",
        name="Middle Creek S.A.R",
        url="http://www.midsar.org/",
        address="PO Box 701",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="866-542-5678",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="95",
        name="PA Canine S.A.R",
        url="http://www.pacsar.org/",
        address="PO Box 673",
        city="Adamstown",
        state="PA",
        zip_code=17501,
        phone="717-484-9577",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="96",
        name="PA Wilderness S.A.R",
        url="http://pawsar.org/",
        address="2650 Columbia Ave",
        city="Lancaster",
        state="PA",
        zip_code=17603,
        phone="717-808-9052",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="97",
        name="Lancaster Airport",
        url="http://www.lancasterairport.com/",
        address="500G Airport Rd",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-569-1221",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="98",
        name="Arconic Mill Products FD",
        url="https://www.arconic.com/carriers/en/locations/overview.asp?loc=Lancaster_PA-_Sheet",
        address="PO Box 3167",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-393-9641",
    ),
    Agency(
        category=IncidentCategory.FIRE,
        station_number="99",
        name="Lancaster County Office of Emergency Management",
        url="https://www.lancema.us/",
        address="P. O. Box 219",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-664-1200",
    ),
]

KNOWN_MEDICAL_AGENCIES = [
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="01",
        name="Ephrata Ambulance",
        url="http://www.ephrataambulance.org/",
        address="528 W Main St",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-733-2821",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="04",
        name="Wellspan EMS",
        url="http://www.wellspan.org/offices-locations/hospitals/wellspan-ephrata-community-hospital/",
        address="PO Box 1002",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-738-6116",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="06",
        name="Lancaster EMS (LEMSA)",
        url="http://www.lemsa.com/",
        address="1829 Lincoln Hwy E",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-481-4841",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="09",
        name="Reinholds Ambulance",
        url="https://www.facebook.com/ReinholdsEMS",
        address="PO Box 33",
        city="Reinholds",
        state="PA",
        zip_code=17569,
        phone="717-336-0217",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="17",
        name="Reamstown Ambulance",
        url="https://www.reamstownfire.com",
        address="PO Box 276",
        city="Reamstown",
        state="PA",
        zip_code=17567,
        phone="717-336-3958",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="24",
        name="Rothsville Ambulance",
        url="https://www.rothsvilleambulance.com",
        address="2071 Main St",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-7805",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="36",
        name="Fivepointville Ambulance",
        url="http://www.fivepointvilleambulance.com/",
        address="1094 Dry Tavern Rd",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-445-5937",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="37",
        name="New Holland Ambulance",
        url="http://www.newhollandambulance.com/",
        address="101 E Franklin St",
        city="New Holland",
        state="PA",
        zip_code=17557,
        phone="717-354-6945",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="43",
        name="Gordonville Ambulance",
        url="http://www.43fireems.com/",
        address="PO Box 14",
        city="Gordonville",
        state="PA",
        zip_code=17529,
        phone="717-768-3869",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="46",
        name="Christiana Ambulance",
        url="http://ccaa52.com/",
        address="PO Box 280",
        city="Christiana",
        state="PA",
        zip_code=17509,
        phone="610-593-8166",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="49",
        name="White Horse Ambulance",
        url="http://www.whitehorsefire.org/",
        address="111 White Horse Rd",
        city="Gap",
        state="PA",
        zip_code=17527,
        phone="717-768-3454",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="56",
        name="Lancaster EMS (LEMSA)",
        url="http://www.lemsa.com/",
        address="1829 Lincoln Hwy E",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-481-4841",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="73",
        name="Franklin & Marshall College QRS",
        url="http://www.fandm.edu/ems",
        address="PO Box 3003",
        city="Lancaster",
        state="PA",
        zip_code=17604,
        phone="717-358-3939",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="77",
        name="Penn State Life Lion EMS",
        url="https://www.pennstatehealth.org/services-treatments/life-lion-emergency-medical-services-critical-care",
        address="126 Keller Ave",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-435-8101",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="82",
        name="Manheim Twp. Ambulance",
        url="http://manheimtownshipems.org/",
        address="1820 Municipal Dr",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-569-6622",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="83",
        name="Code 3 EMS",
        url="https://www.facebook.com/Code-3-EMS-106102687620495",
        address="520 Union St",
        city="Columbia",
        state="PA",
        zip_code=17512,
        phone="717-278-8732",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="85",
        name="Warwick Ambulance",
        url="http://warwickems.org/",
        address="PO Box 42",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-627-0143",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="86",
        name="Northwest EMS",
        url="http://nwems86.org/",
        address="PO Box 384",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-361-8220",
    ),
    Agency(
        category=IncidentCategory.MEDICAL,
        station_number="88",
        name="Wakefield Ambulance",
        url="http://wakefieldems.org/",
        address="PO Box 86",
        city="Peach Bottom",
        state="PA",
        zip_code=17563,
        phone="717-955-0152",
    ),
]

KNOWN_TRAFFIC_AGENCIES = [
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="11",
        name="Lancaster County Constables",
        url="https://www.facebook.com/Lancaster-County-Constables-1670167773276477",
        address="PO Box 692",
        city="East Petersburg",
        state="PA",
        zip_code=17520,
        phone="",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="12",
        name="Lancaster County Sheriff's Dept.",
        url="https://co.lancaster.pa.us/160/Sheriffs-Office",
        address="50 N Duke St",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-299-8200",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="14",
        name="Lancaster County Parks Dept.",
        url="http://www.lancastercountyparks.org/",
        address="1052 Rockford Rd",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-295-3605",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="15",
        name="Lancaster County District Attorney",
        url="https://co.lancaster.pa.us/138/District-Attorney",
        address="50 N Duke St",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-299-8100",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="16",
        name="Manor Twp. Police",
        url="http://manortownship.net/police",
        address="950 W Fairway Dr",
        city="Lancaster",
        state="PA",
        zip_code=17603,
        phone="717-299-5231",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="17",
        name="Millersville Borough Police",
        url="http://millersvilleborough.org/departments/police-2",
        address="100 Municipal Dr",
        city="Millersville",
        state="PA",
        zip_code=17551,
        phone="717-872-4657",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="19",
        name="East Hempfield Twp. Police",
        url="http://www.easthempfield.org/187/Police-Department",
        address="PO Box 128",
        city="Landisville",
        state="PA",
        zip_code=17538,
        phone="717-898-3103",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="21",
        name="Strasburg Borough Police",
        url="https://lancaster.crimewatchpa.com/strasburgpd/11416",
        address="145 Precision Ave",
        city="Strasburg",
        state="PA",
        zip_code=17579,
        phone="717-687-7128",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="23",
        name="Pequea Twp. Police",
        url="https://lancaster.crimewatchpa.com/southernregionalpolice/13620",
        address="53 Marticville Road",
        city="Willow Street",
        state="PA",
        zip_code=17584,
        phone="717-945-7546",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="24",
        name="Elizabethtown Borough Police",
        url="https://www.etownonline.com/police-department",
        address="600 S Hanover St",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-367-6540",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="25",
        name="Lititz Borough Police",
        url="https://lancaster.crimewatchpa.com/lititzpd/11450",
        address="7 S Broad St",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-6393",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="26",
        name="West Lampeter Twp. Police",
        url="http://www.westlampeter.com/2156/Police",
        address="PO Box 296",
        city="Lampeter",
        state="PA",
        zip_code=17537,
        phone="717-464-2421",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="27",
        name="Susquehanna Regional Police",
        url="http://srpd27.com/",
        address="188 Rock Point Rd",
        city="Marietta",
        state="PA",
        zip_code=17547,
        phone="717-426-1164",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="28",
        name="Quarryville Borough Police",
        url="http://quarryvilleborough.com/services/police",
        address="300 Saint Catherine St",
        city="Quarryville",
        state="PA",
        zip_code=17566,
        phone="717-786-2101",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="33",
        name="Mount Joy Borough Police",
        url="http://www.mountjoyborough.com/police-department",
        address="21 E Main St",
        city="Mount Joy",
        state="PA",
        zip_code=17552,
        phone="717-653-1650",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="34",
        name="Manheim Borough Police",
        url="http://www.manheimpolice.org/",
        address="211 N Charlotte St",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-665-2481",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="35",
        name="Northwest Regional Police",
        url="http://nwrpd.org/",
        address="8855 Elizabethtown Rd",
        city="Elizabethtown",
        state="PA",
        zip_code=17022,
        phone="717-367-8481",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="39",
        name="West Hempfield Twp. Police",
        url="http://www.westhempfield.org/subpage.php?link=police",
        address="3401 Marietta Ave",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-285-5191",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="42",
        name="Lancaster City Police",
        url="http://www.lancasterpolice.com/",
        address="39 W Chestnut St",
        city="Lancaster",
        state="PA",
        zip_code=17603,
        phone="717-735-3300",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="43",
        name="Christiana Borough Police",
        url="https://www.policeapp.com/Christiana-Borough-PA-Police-Department/423/",
        address="PO Box 135",
        city="Christiana",
        state="PA",
        zip_code=17509,
        phone="610-593-2234",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="48",
        name="East Lampeter Twp. Police",
        url="https://lancaster.crimewatchpa.com/eastlampeter/9004",
        address="2250 Old Philadelphia Pike",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-291-4676",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="51",
        name="Manheim Twp. Police",
        url="http://www.manheimtownship.org/index.aspx?nid=187",
        address="1825 Municipal Dr",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-569-6401",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="62",
        name="Columbia Borough Police",
        url="https://lancaster.crimewatchpa.com/columbiapd/10552",
        address="PO Box 509",
        city="Columbia",
        state="PA",
        zip_code=17512,
        phone="717-684-7735",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="77",
        name="Amtrak Police",
        url="https://police.amtrak.com/",
        address="53 McGovern Ave",
        city="Lancaster",
        state="PA",
        zip_code=17602,
        phone="717-291-5005",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="78",
        name="East Cocalico Twp. Police",
        url="https://lancaster.crimewatchpa.com/eastcocalicopd",
        address="100 Hill Rd",
        city="Denver",
        state="PA",
        zip_code=17517,
        phone="717-336-1725",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="79",
        name="East Earl Twp. Police",
        url="https://lancaster.crimewatchpa.com/eastearlpd/11499",
        address="128 Toddy Dr",
        city="East Earl",
        state="PA",
        zip_code=17519,
        phone="717-354-2211",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="82",
        name="Ephrata Police",
        url="http://www.ephrataboro.org/2211/Police",
        address="124 S State St",
        city="Ephrata",
        state="PA",
        zip_code=17522,
        phone="717-738-9200",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="84",
        name="New Holland Police",
        url="http://newhollandborough.org/departments/police",
        address="436 E Main St",
        city="New Holland",
        state="PA",
        zip_code=17557,
        phone="717-354-4647",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="86",
        name="Northern Regional Police",
        url="https://lancaster.crimewatchpa.com/nlcrpd/8795",
        address="860 Durlach Rd",
        city="Stevens",
        state="PA",
        zip_code=17578,
        phone="717-733-0965",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="88",
        name="West Earl Twp. Police",
        url="https://lancaster.crimewatchpa.com/westearlpd",
        address="PO Box 787",
        city="Brownstown",
        state="PA",
        zip_code=17508,
        phone="717-859-1411",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="91",
        name="Lancaster County-Wide Communications",
        url="http://www.lcwc911.us/lcwc",
        address="PO Box 487",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-664-1100",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="92",
        name="Lancaster County Coroner's Office",
        url="https://co.lancaster.pa.us/133/Coroner",
        address="2080 Spring Valley Rd",
        city="Lancaster",
        state="PA",
        zip_code=17601,
        phone="717-735-2123",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="93",
        name="Millersville University Police",
        url="https://www.millersville.edu/police/",
        address="37 W Frederick St Boyer Building",
        city="Millersville",
        state="PA",
        zip_code=17551,
        phone="717-871-4357",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="94",
        name="Franklin & Marshall College Public Safety",
        url="http://www.fandm.edu/publicsafety",
        address="PO Box 3003",
        city="Lancaster",
        state="PA",
        zip_code=17604,
        phone="717-291-3939",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="96",
        name="PA Game Commission",
        url="http://www.pgc.state.pa.us/",
        address="253 Snyder Rd",
        city="Reading",
        state="PA",
        zip_code=19605,
        phone="610-926-3136",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="97",
        name="PA Fish Commission",
        url="http://www.fishandboat.com/Pages/default.aspx",
        address="255 W Brubaker Valley Rd",
        city="Lititz",
        state="PA",
        zip_code=17543,
        phone="717-626-0228",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="98",
        name="FBI",
        url="http://www.fbi.gov/",
        address="228 Walnut St, Unit 670",
        city="Harrisburg",
        state="PA",
        zip_code=17101,
        phone="215-418-4000",
    ),
    Agency(
        category=IncidentCategory.TRAFFIC,
        station_number="99",
        name="Lancaster County Office of Emergency Management",
        url="https://www.lancema.us/",
        address="P.O. Box 219",
        city="Manheim",
        state="PA",
        zip_code=17545,
        phone="717-664-1200",
    ),
]

ALL_KNOWN_AGENCIES = (
    KNOWN_FIRE_AGENCIES + KNOWN_MEDICAL_AGENCIES + KNOWN_TRAFFIC_AGENCIES
)
